@@ -10,12 +10,13 @@
 
 #include <QObject>
 #include <QPoint>
+#include <QVariantMap>
 
-#include "milou_export.h"
+class QMimeData;
 
 namespace Milou
 {
-class MILOU_EXPORT MouseHelper : public QObject
+class MouseHelper : public QObject
 {
     Q_OBJECT
 
@@ -24,6 +25,12 @@ public:
     ~MouseHelper() override;
 
     Q_INVOKABLE QPointF globalMousePosition() const;
+
+    /*
+     * Converts QMimeData to QVariantMap
+     * @internal will be removed after https://codereview.qt-project.org/c/qt/qtdeclarative/+/491548
+     */
+    Q_INVOKABLE QVariantMap generateMimeDataMap(QMimeData *data) const;
 };
 
 }
